// Copyright 2010 The Go Authors. All rights reserved.
// Use of this source code is governed by a BSD-style
// license that can be found in the LICENSE file.

package tls

import (
	"bytes"
	"flag"
	"io"
	"net"
	"os"
	"testing"
)

func testClientScript(t *testing.T, name string, clientScript [][]byte, config *Config) {
	c, s := net.Pipe()
	cli := Client(c, config)
	go func() {
		cli.Write([]byte("hello\n"))
		cli.Close()
		c.Close()
	}()

	defer c.Close()
	for i, b := range clientScript {
		if i%2 == 1 {
			s.Write(b)
			continue
		}
		bb := make([]byte, len(b))
		_, err := io.ReadFull(s, bb)
		if err != nil {
			t.Fatalf("%s #%d: %s", name, i, err)
		}
		if !bytes.Equal(b, bb) {
			t.Fatalf("%s #%d: mismatch on read: got:%x want:%x", name, i, bb, b)
		}
	}
}

func TestHandshakeClientRC4(t *testing.T) {
	var config = *testConfig
	config.CipherSuites = []uint16{TLS_RSA_WITH_RC4_128_SHA}
	testClientScript(t, "RC4", rc4ClientScript, &config)
}

func TestHandshakeClientECDHEAES(t *testing.T) {
	var config = *testConfig
	config.CipherSuites = []uint16{TLS_ECDHE_RSA_WITH_AES_128_CBC_SHA}
	testClientScript(t, "ECDHE-AES", ecdheAESClientScript, &config)
}

var connect = flag.Bool("connect", false, "connect to a TLS server on :10443")

func TestRunClient(t *testing.T) {
	if !*connect {
		return
	}

	tcpConn, err := net.Dial("tcp", "127.0.0.1:10443")
	if err != nil {
		t.Fatal(err)
	}

	record := &recordingConn{
		Conn: tcpConn,
	}

	config := GetTestConfig()
	conn := Client(record, config)
	if err := conn.Handshake(); err != nil {
		t.Fatalf("error from TLS handshake: %s", err)
	}

	conn.Write([]byte("hello\n"))
	conn.Close()

	record.WriteTo(os.Stdout)
}

func TestEmptyRecords(t *testing.T) {
	// emptyRecordScript contains a TLS connection with an empty record as
	// the first application data from the server. This test ensures that
	// the empty record doesn't cause (0, nil) to be returned from
	// Conn.Read.
	config := *testConfig
	config.CipherSuites = []uint16{TLS_RSA_WITH_AES_256_CBC_SHA}

	c, s := net.Pipe()
	cli := Client(c, &config)
	go func() {
		buf := make([]byte, 1024)
		n, err := cli.Read(buf)
		defer c.Close()
		defer cli.Close()

		if err != nil {
			t.Fatalf("error reading from tls.Client: %s", err)
		}
		const expectedLength = 197
		if n != expectedLength {
			t.Fatalf("incorrect length reading from tls.Client, got %d, want %d", n, expectedLength)
		}
	}()

	defer c.Close()
	for i, b := range emptyRecordScript {
		if i%2 == 1 {
			s.Write(b)
			continue
		}
		bb := make([]byte, len(b))
		_, err := io.ReadFull(s, bb)
		if err != nil {
			t.Fatalf("#%d: %s", i, err)
		}
		if !bytes.Equal(b, bb) {
			t.Fatalf("#%d: mismatch on read: got:%x want:%x", i, bb, b)
		}
	}
}

// Script of interaction with gnutls implementation.
// The values for this test are obtained by building and running in client mode:
//   % go test -test.run "TestRunClient" -connect
// The recorded bytes are written to stdout.
//
// The server private key is:
// -----BEGIN RSA PRIVATE KEY-----
// MIIBPAIBAAJBAJ+zw4Qnlf8SMVIPFe9GEcStgOY2Ww/dgNdhjeD8ckUJNP5VZkVD
// TGiXav6ooKXfX3j/7tdkuD8Ey2//Kv7+ue0CAwEAAQJAN6W31vDEP2DjdqhzCDDu
// OA4NACqoiFqyblo7yc2tM4h4xMbC3Yx5UKMN9ZkCtX0gzrz6DyF47bdKcWBzNWCj
// gQIhANEoojVt7hq+SQ6MCN6FTAysGgQf56Q3TYoJMoWvdiXVAiEAw3e3rc+VJpOz
// rHuDo6bgpjUAAXM+v3fcpsfZSNO6V7kCIQCtbVjanpUwvZkMI9by02oUk9taki3b
// PzPfAfNPYAbCJQIhAJXNQDWyqwn/lGmR11cqY2y9nZ1+5w3yHGatLrcDnQHxAiEA
// vnlEGo8K85u+KwIOimM48ZG8oTk7iFdkqLJR1utT3aU=
// -----END RSA PRIVATE KEY-----
//
// and certificate is:
// -----BEGIN CERTIFICATE-----
// MIICKzCCAdWgAwIBAgIJALE1E2URIMWSMA0GCSqGSIb3DQEBBQUAMEUxCzAJBgNV
// BAYTAkFVMRMwEQYDVQQIEwpTb21lLVN0YXRlMSEwHwYDVQQKExhJbnRlcm5ldCBX
// aWRnaXRzIFB0eSBMdGQwHhcNMTIwNDA2MTcxMDEzWhcNMTUwNDA2MTcxMDEzWjBF
// MQswCQYDVQQGEwJBVTETMBEGA1UECBMKU29tZS1TdGF0ZTEhMB8GA1UEChMYSW50
// ZXJuZXQgV2lkZ2l0cyBQdHkgTHRkMFwwDQYJKoZIhvcNAQEBBQADSwAwSAJBAJ+z
// w4Qnlf8SMVIPFe9GEcStgOY2Ww/dgNdhjeD8ckUJNP5VZkVDTGiXav6ooKXfX3j/
// 7tdkuD8Ey2//Kv7+ue0CAwEAAaOBpzCBpDAdBgNVHQ4EFgQUeKaXmmO1xaGlM7oi
// fCNuWxt6zCswdQYDVR0jBG4wbIAUeKaXmmO1xaGlM7oifCNuWxt6zCuhSaRHMEUx
// CzAJBgNVBAYTAkFVMRMwEQYDVQQIEwpTb21lLVN0YXRlMSEwHwYDVQQKExhJbnRl
// cm5ldCBXaWRnaXRzIFB0eSBMdGSCCQCxNRNlESDFkjAMBgNVHRMEBTADAQH/MA0G
// CSqGSIb3DQEBBQUAA0EAhTZAc8G7GtrUWZ8tonAxRnTsg26oyDxRrzms7EC86CJG
// HZnWRiok1IsFCEv7NRFukrt3uuQSu/TIXpyBqJdgTA==
// -----END CERTIFICATE-----
var rc4ClientScript = [][]byte{
	{
		0x16, 0x03, 0x01, 0x00, 0x4a, 0x01, 0x00, 0x00,
		0x46, 0x03, 0x01, 0x00, 0x00, 0x00, 0x00, 0x00,
		0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
		0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
		0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
		0x00, 0x00, 0x00, 0x00, 0x00, 0x02, 0x00, 0x05,
		0x01, 0x00, 0x00, 0x1b, 0x00, 0x05, 0x00, 0x05,
		0x01, 0x00, 0x00, 0x00, 0x00, 0x00, 0x0a, 0x00,
		0x08, 0x00, 0x06, 0x00, 0x17, 0x00, 0x18, 0x00,
		0x19, 0x00, 0x0b, 0x00, 0x02, 0x01, 0x00,
	},

	{
		0x16, 0x03, 0x01, 0x00, 0x4a, 0x02, 0x00, 0x00,
		0x46, 0x03, 0x01, 0x4d, 0x0a, 0x56, 0x16, 0xb5,
		0x91, 0xd1, 0xcb, 0x80, 0x4d, 0xc7, 0x46, 0xf3,
		0x37, 0x0c, 0xef, 0xea, 0x64, 0x11, 0x14, 0x56,
		0x97, 0x9b, 0xc5, 0x67, 0x08, 0xb7, 0x13, 0xea,
		0xf8, 0xc9, 0xb3, 0x20, 0xe2, 0xfc, 0x41, 0xf6,
		0x96, 0x90, 0x9d, 0x43, 0x9b, 0xe9, 0x6e, 0xf8,
		0x41, 0x16, 0xcc, 0xf3, 0xc7, 0xde, 0xda, 0x5a,
		0xa1, 0x33, 0x69, 0xe2, 0xde, 0x5b, 0xaf, 0x2a,
		0x92, 0xe7, 0xd4, 0xa0, 0x00, 0x05, 0x00, 0x16,
		0x03, 0x01, 0x01, 0xf7, 0x0b, 0x00, 0x01, 0xf3,
		0x00, 0x01, 0xf0, 0x00, 0x01, 0xed, 0x30, 0x82,
		0x01, 0xe9, 0x30, 0x82, 0x01, 0x52, 0x02, 0x01,
		0x06, 0x30, 0x0d, 0x06, 0x09, 0x2a, 0x86, 0x48,
		0x86, 0xf7, 0x0d, 0x01, 0x01, 0x04, 0x05, 0x00,
		0x30, 0x5b, 0x31, 0x0b, 0x30, 0x09, 0x06, 0x03,
		0x55, 0x04, 0x06, 0x13, 0x02, 0x41, 0x55, 0x31,
		0x13, 0x30, 0x11, 0x06, 0x03, 0x55, 0x04, 0x08,
		0x13, 0x0a, 0x51, 0x75, 0x65, 0x65, 0x6e, 0x73,
		0x6c, 0x61, 0x6e, 0x64, 0x31, 0x1a, 0x30, 0x18,
		0x06, 0x03, 0x55, 0x04, 0x0a, 0x13, 0x11, 0x43,
		0x72, 0x79, 0x70, 0x74, 0x53, 0x6f, 0x66, 0x74,
		0x20, 0x50, 0x74, 0x79, 0x20, 0x4c, 0x74, 0x64,
		0x31, 0x1b, 0x30, 0x19, 0x06, 0x03, 0x55, 0x04,
		0x03, 0x13, 0x12, 0x54, 0x65, 0x73, 0x74, 0x20,
		0x43, 0x41, 0x20, 0x28, 0x31, 0x30, 0x32, 0x34,
		0x20, 0x62, 0x69, 0x74, 0x29, 0x30, 0x1e, 0x17,
		0x0d, 0x30, 0x30, 0x31, 0x30, 0x31, 0x36, 0x32,
		0x32, 0x33, 0x31, 0x30, 0x33, 0x5a, 0x17, 0x0d,
		0x30, 0x33, 0x30, 0x31, 0x31, 0x34, 0x32, 0x32,
		0x33, 0x31, 0x30, 0x33, 0x5a, 0x30, 0x63, 0x31,
		0x0b, 0x30, 0x09, 0x06, 0x03, 0x55, 0x04, 0x06,
		0x13, 0x02, 0x41, 0x55, 0x31, 0x13, 0x30, 0x11,
		0x06, 0x03, 0x55, 0x04, 0x08, 0x13, 0x0a, 0x51,
		0x75, 0x65, 0x65, 0x6e, 0x73, 0x6c, 0x61, 0x6e,
		0x64, 0x31, 0x1a, 0x30, 0x18, 0x06, 0x03, 0x55,
		0x04, 0x0a, 0x13, 0x11, 0x43, 0x72, 0x79, 0x70,
		0x74, 0x53, 0x6f, 0x66, 0x74, 0x20, 0x50, 0x74,
		0x79, 0x20, 0x4c, 0x74, 0x64, 0x31, 0x23, 0x30,
		0x21, 0x06, 0x03, 0x55, 0x04, 0x03, 0x13, 0x1a,
		0x53, 0x65, 0x72, 0x76, 0x65, 0x72, 0x20, 0x74,
		0x65, 0x73, 0x74, 0x20, 0x63, 0x65, 0x72, 0x74,
		0x20, 0x28, 0x35, 0x31, 0x32, 0x20, 0x62, 0x69,
		0x74, 0x29, 0x30, 0x5c, 0x30, 0x0d, 0x06, 0x09,
		0x2a, 0x86, 0x48, 0x86, 0xf7, 0x0d, 0x01, 0x01,
		0x01, 0x05, 0x00, 0x03, 0x4b, 0x00, 0x30, 0x48,
		0x02, 0x41, 0x00, 0x9f, 0xb3, 0xc3, 0x84, 0x27,
		0x95, 0xff, 0x12, 0x31, 0x52, 0x0f, 0x15, 0xef,
		0x46, 0x11, 0xc4, 0xad, 0x80, 0xe6, 0x36, 0x5b,
		0x0f, 0xdd, 0x80, 0xd7, 0x61, 0x8d, 0xe0, 0xfc,
		0x72, 0x45, 0x09, 0x34, 0xfe, 0x55, 0x66, 0x45,
		0x43, 0x4c, 0x68, 0x97, 0x6a, 0xfe, 0xa8, 0xa0,
		0xa5, 0xdf, 0x5f, 0x78, 0xff, 0xee, 0xd7, 0x64,
		0xb8, 0x3f, 0x04, 0xcb, 0x6f, 0xff, 0x2a, 0xfe,
		0xfe, 0xb9, 0xed, 0x02, 0x03, 0x01, 0x00, 0x01,
		0x30, 0x0d, 0x06, 0x09, 0x2a, 0x86, 0x48, 0x86,
		0xf7, 0x0d, 0x01, 0x01, 0x04, 0x05, 0x00, 0x03,
		0x81, 0x81, 0x00, 0x93, 0xd2, 0x0a, 0xc5, 0x41,
		0xe6, 0x5a, 0xa9, 0x86, 0xf9, 0x11, 0x87, 0xe4,
		0xdb, 0x45, 0xe2, 0xc5, 0x95, 0x78, 0x1a, 0x6c,
		0x80, 0x6d, 0x73, 0x1f, 0xb4, 0x6d, 0x44, 0xa3,
		0xba, 0x86, 0x88, 0xc8, 0x58, 0xcd, 0x1c, 0x06,
		0x35, 0x6c, 0x44, 0x62, 0x88, 0xdf, 0xe4, 0xf6,
		0x64, 0x61, 0x95, 0xef, 0x4a, 0xa6, 0x7f, 0x65,
		0x71, 0xd7, 0x6b, 0x88, 0x39, 0xf6, 0x32, 0xbf,
		0xac, 0x93, 0x67, 0x69, 0x51, 0x8c, 0x93, 0xec,
		0x48, 0x5f, 0xc9, 0xb1, 0x42, 0xf9, 0x55, 0xd2,
		0x7e, 0x4e, 0xf4, 0xf2, 0x21, 0x6b, 0x90, 0x57,
		0xe6, 0xd7, 0x99, 0x9e, 0x41, 0xca, 0x80, 0xbf,
		0x1a, 0x28, 0xa2, 0xca, 0x5b, 0x50, 0x4a, 0xed,
		0x84, 0xe7, 0x82, 0xc7, 0xd2, 0xcf, 0x36, 0x9e,
		0x6a, 0x67, 0xb9, 0x88, 0xa7, 0xf3, 0x8a, 0xd0,
		0x04, 0xf8, 0xe8, 0xc6, 0x17, 0xe3, 0xc5, 0x29,
		0xbc, 0x17, 0xf1, 0x16, 0x03, 0x01, 0x00, 0x04,
		0x0e, 0x00, 0x00, 0x00,
	},

	{
		0x16, 0x03, 0x01, 0x00, 0x46, 0x10, 0x00, 0x00,
		0x42, 0x00, 0x40, 0x87, 0xa1, 0x1f, 0x14, 0xe1,
		0xfb, 0x91, 0xac, 0x58, 0x2e, 0xf3, 0x71, 0xce,
		0x01, 0x85, 0x2c, 0xc7, 0xfe, 0x84, 0x87, 0x82,
		0xb7, 0x57, 0xdb, 0x37, 0x4d, 0x46, 0x83, 0x67,
		0x52, 0x82, 0x51, 0x01, 0x95, 0x23, 0x68, 0x69,
		0x6b, 0xd0, 0xa7, 0xa7, 0xe5, 0x88, 0xd0, 0x47,
		0x71, 0xb8, 0xd2, 0x03, 0x05, 0x25, 0x56, 0x5c,
		0x10, 0x08, 0xc6, 0x9b, 0xd4, 0x67, 0xcd, 0x28,
		0xbe, 0x9c, 0x48, 0x14, 0x03, 0x01, 0x00, 0x01,
		0x01, 0x16, 0x03, 0x01, 0x00, 0x24, 0xc1, 0xb8,
		0xd3, 0x7f, 0xc5, 0xc2, 0x5a, 0x1d, 0x6d, 0x5b,
		0x2d, 0x5c, 0x82, 0x87, 0xc2, 0x6f, 0x0d, 0x63,
		0x7b, 0x72, 0x2b, 0xda, 0x69, 0xc4, 0xfe, 0x3c,
		0x84, 0xa1, 0x5a, 0x62, 0x38, 0x37, 0xc6, 0x54,
		0x25, 0x2a,
	},

	{
		0x14, 0x03, 0x01, 0x00, 0x01, 0x01, 0x16, 0x03,
		0x01, 0x00, 0x24, 0xea, 0x88, 0x9c, 0x00, 0xf6,
		0x35, 0xb8, 0x42, 0x7f, 0x15, 0x17, 0x76, 0x5e,
		0x4b, 0x24, 0xcb, 0x7e, 0xa0, 0x7b, 0xc3, 0x70,
		0x52, 0x0a, 0x88, 0x2a, 0x7a, 0x45, 0x59, 0x90,
		0x59, 0xac, 0xc6, 0xb5, 0x56, 0x55, 0x96,
	},
}

var ecdheAESClientScript = [][]byte{
	{
		0x16, 0x03, 0x01, 0x00, 0x4a, 0x01, 0x00, 0x00,
		0x46, 0x03, 0x01, 0x00, 0x00, 0x00, 0x00, 0x00,
		0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
		0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
		0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
		0x00, 0x00, 0x00, 0x00, 0x00, 0x02, 0xc0, 0x13,
		0x01, 0x00, 0x00, 0x1b, 0x00, 0x05, 0x00, 0x05,
		0x01, 0x00, 0x00, 0x00, 0x00, 0x00, 0x0a, 0x00,
		0x08, 0x00, 0x06, 0x00, 0x17, 0x00, 0x18, 0x00,
		0x19, 0x00, 0x0b, 0x00, 0x02, 0x01, 0x00,
	},
	{
		0x16, 0x03, 0x01, 0x00, 0x52, 0x02, 0x00, 0x00,
		0x4e, 0x03, 0x01, 0x50, 0xad, 0x72, 0xb1, 0x14,
		0x45, 0xce, 0x0a, 0x95, 0xf9, 0x63, 0xef, 0xa8,
		0xe5, 0x07, 0x34, 0x04, 0xe9, 0x08, 0x0f, 0x38,
		0xe4, 0x28, 0x27, 0x91, 0x07, 0x03, 0xe2, 0xfe,
		0xe3, 0x25, 0xf7, 0x20, 0x08, 0x42, 0xa2, 0x01,
		0x69, 0x53, 0xf0, 0xd9, 0x4c, 0xfa, 0x01, 0xa1,
		0xce, 0x4b, 0xf8, 0x28, 0x21, 0xad, 0x06, 0xbe,
		0xe0, 0x1b, 0x3b, 0xf7, 0xec, 0xd2, 0x52, 0xae,
		0x2a, 0x57, 0xb7, 0xa8, 0xc0, 0x13, 0x00, 0x00,
		0x06, 0x00, 0x0b, 0x00, 0x02, 0x01, 0x00, 0x16,
		0x03, 0x01, 0x02, 0x39, 0x0b, 0x00, 0x02, 0x35,
		0x00, 0x02, 0x32, 0x00, 0x02, 0x2f, 0x30, 0x82,
		0x02, 0x2b, 0x30, 0x82, 0x01, 0xd5, 0xa0, 0x03,
		0x02, 0x01, 0x02, 0x02, 0x09, 0x00, 0xb1, 0x35,
		0x13, 0x65, 0x11, 0x20, 0xc5, 0x92, 0x30, 0x0d,
		0x06, 0x09, 0x2a, 0x86, 0x48, 0x86, 0xf7, 0x0d,
		0x01, 0x01, 0x05, 0x05, 0x00, 0x30, 0x45, 0x31,
		0x0b, 0x30, 0x09, 0x06, 0x03, 0x55, 0x04, 0x06,
		0x13, 0x02, 0x41, 0x55, 0x31, 0x13, 0x30, 0x11,
		0x06, 0x03, 0x55, 0x04, 0x08, 0x13, 0x0a, 0x53,
		0x6f, 0x6d, 0x65, 0x2d, 0x53, 0x74, 0x61, 0x74,
		0x65, 0x31, 0x21, 0x30, 0x1f, 0x06, 0x03, 0x55,
		0x04, 0x0a, 0x13, 0x18, 0x49, 0x6e, 0x74, 0x65,
		0x72, 0x6e, 0x65, 0x74, 0x20, 0x57, 0x69, 0x64,
		0x67, 0x69, 0x74, 0x73, 0x20, 0x50, 0x74, 0x79,
		0x20, 0x4c, 0x74, 0x64, 0x30, 0x1e, 0x17, 0x0d,
		0x31, 0x32, 0x30, 0x34, 0x30, 0x36, 0x31, 0x37,
		0x31, 0x30, 0x31, 0x33, 0x5a, 0x17, 0x0d, 0x31,
		0x35, 0x30, 0x34, 0x30, 0x36, 0x31, 0x37, 0x31,
		0x30, 0x31, 0x33, 0x5a, 0x30, 0x45, 0x31, 0x0b,
		0x30, 0x09, 0x06, 0x03, 0x55, 0x04, 0x06, 0x13,
		0x02, 0x41, 0x55, 0x31, 0x13, 0x30, 0x11, 0x06,
		0x03, 0x55, 0x04, 0x08, 0x13, 0x0a, 0x53, 0x6f,
		0x6d, 0x65, 0x2d, 0x53, 0x74, 0x61, 0x74, 0x65,
		0x31, 0x21, 0x30, 0x1f, 0x06, 0x03, 0x55, 0x04,
		0x0a, 0x13, 0x18, 0x49, 0x6e, 0x74, 0x65, 0x72,
		0x6e, 0x65, 0x74, 0x20, 0x57, 0x69, 0x64, 0x67,
		0x69, 0x74, 0x73, 0x20, 0x50, 0x74, 0x79, 0x20,
		0x4c, 0x74, 0x64, 0x30, 0x5c, 0x30, 0x0d, 0x06,
		0x09, 0x2a, 0x86, 0x48, 0x86, 0xf7, 0x0d, 0x01,
		0x01, 0x01, 0x05, 0x00, 0x03, 0x4b, 0x00, 0x30,
		0x48, 0x02, 0x41, 0x00, 0x9f, 0xb3, 0xc3, 0x84,
		0x27, 0x95, 0xff, 0x12, 0x31, 0x52, 0x0f, 0x15,
		0xef, 0x46, 0x11, 0xc4, 0xad, 0x80, 0xe6, 0x36,
		0x5b, 0x0f, 0xdd, 0x80, 0xd7, 0x61, 0x8d, 0xe0,
		0xfc, 0x72, 0x45, 0x09, 0x34, 0xfe, 0x55, 0x66,
		0x45, 0x43, 0x4c, 0x68, 0x97, 0x6a, 0xfe, 0xa8,
		0xa0, 0xa5, 0xdf, 0x5f, 0x78, 0xff, 0xee, 0xd7,
		0x64, 0xb8, 0x3f, 0x04, 0xcb, 0x6f, 0xff, 0x2a,
		0xfe, 0xfe, 0xb9, 0xed, 0x02, 0x03, 0x01, 0x00,
		0x01, 0xa3, 0x81, 0xa7, 0x30, 0x81, 0xa4, 0x30,
		0x1d, 0x06, 0x03, 0x55, 0x1d, 0x0e, 0x04, 0x16,
		0x04, 0x14, 0x78, 0xa6, 0x97, 0x9a, 0x63, 0xb5,
		0xc5, 0xa1, 0xa5, 0x33, 0xba, 0x22, 0x7c, 0x23,
		0x6e, 0x5b, 0x1b, 0x7a, 0xcc, 0x2b, 0x30, 0x75,
		0x06, 0x03, 0x55, 0x1d, 0x23, 0x04, 0x6e, 0x30,
		0x6c, 0x80, 0x14, 0x78, 0xa6, 0x97, 0x9a, 0x63,
		0xb5, 0xc5, 0xa1, 0xa5, 0x33, 0xba, 0x22, 0x7c,
		0x23, 0x6e, 0x5b, 0x1b, 0x7a, 0xcc, 0x2b, 0xa1,
		0x49, 0xa4, 0x47, 0x30, 0x45, 0x31, 0x0b, 0x30,
		0x09, 0x06, 0x03, 0x55, 0x04, 0x06, 0x13, 0x02,
		0x41, 0x55, 0x31, 0x13, 0x30, 0x11, 0x06, 0x03,
		0x55, 0x04, 0x08, 0x13, 0x0a, 0x53, 0x6f, 0x6d,
		0x65, 0x2d, 0x53, 0x74, 0x61, 0x74, 0x65, 0x31,
		0x21, 0x30, 0x1f, 0x06, 0x03, 0x55, 0x04, 0x0a,
		0x13, 0x18, 0x49, 0x6e, 0x74, 0x65, 0x72, 0x6e,
		0x65, 0x74, 0x20, 0x57, 0x69, 0x64, 0x67, 0x69,
		0x74, 0x73, 0x20, 0x50, 0x74, 0x79, 0x20, 0x4c,
		0x74, 0x64, 0x82, 0x09, 0x00, 0xb1, 0x35, 0x13,
		0x65, 0x11, 0x20, 0xc5, 0x92, 0x30, 0x0c, 0x06,
		0x03, 0x55, 0x1d, 0x13, 0x04, 0x05, 0x30, 0x03,
		0x01, 0x01, 0xff, 0x30, 0x0d, 0x06, 0x09, 0x2a,
		0x86, 0x48, 0x86, 0xf7, 0x0d, 0x01, 0x01, 0x05,
		0x05, 0x00, 0x03, 0x41, 0x00, 0x85, 0x36, 0x40,
		0x73, 0xc1, 0xbb, 0x1a, 0xda, 0xd4, 0x59, 0x9f,
		0x2d, 0xa2, 0x70, 0x31, 0x46, 0x74, 0xec, 0x83,
		0x6e, 0xa8, 0xc8, 0x3c, 0x51, 0xaf, 0x39, 0xac,
		0xec, 0x40, 0xbc, 0xe8, 0x22, 0x46, 0x1d, 0x99,
		0xd6, 0x46, 0x2a, 0x24, 0xd4, 0x8b, 0x05, 0x08,
		0x4b, 0xfb, 0x35, 0x11, 0x6e, 0x92, 0xbb, 0x77,
		0xba, 0xe4, 0x12, 0xbb, 0xf4, 0xc8, 0x5e, 0x9c,
		0x81, 0xa8, 0x97, 0x60, 0x4c, 0x16, 0x03, 0x01,
		0x00, 0x8b, 0x0c, 0x00, 0x00, 0x87, 0x03, 0x00,
		0x17, 0x41, 0x04, 0x1c, 0x8f, 0x9c, 0x6d, 0xe7,
		0xab, 0x3e, 0xf8, 0x0a, 0x5d, 0xe1, 0x86, 0xb4,
		0xe2, 0x8e, 0xb2, 0x1c, 0x3b, 0xd9, 0xb6, 0x08,
		0x80, 0x58, 0x21, 0xe9, 0x0e, 0xc6, 0x66, 0x67,
		0x97, 0xcb, 0xb9, 0x92, 0x07, 0x00, 0xc4, 0xe5,
		0xec, 0x5f, 0xb4, 0xe2, 0x20, 0xa9, 0xc9, 0x62,
		0xd0, 0x98, 0xd5, 0xe3, 0x53, 0xff, 0xd0, 0x0a,
		0x6e, 0x29, 0x69, 0x39, 0x2a, 0x4b, 0x5c, 0xd8,
		0x6c, 0xf5, 0xfe, 0x00, 0x40, 0x35, 0xa7, 0x26,
		0x2e, 0xc2, 0x48, 0x93, 0x32, 0xf7, 0x7d, 0x0f,
		0x0d, 0x77, 0x56, 0x9a, 0x85, 0x0c, 0xa6, 0x74,
		0x06, 0xb8, 0x3d, 0x90, 0x56, 0x12, 0x63, 0xff,
		0x00, 0x5e, 0x0f, 0xf7, 0x24, 0xf7, 0xdb, 0x48,
		0x71, 0xe9, 0x2e, 0x03, 0xd3, 0xfa, 0x3a, 0xae,
		0xa0, 0xc1, 0x77, 0x3c, 0x4c, 0x59, 0xce, 0x33,
		0x1a, 0xd2, 0x47, 0x83, 0xfa, 0xea, 0xd8, 0x1e,
		0x06, 0xe7, 0x7d, 0xa0, 0x9b, 0x16, 0x03, 0x01,
		0x00, 0x04, 0x0e, 0x00, 0x00, 0x00,
	},
	{
		0x16, 0x03, 0x01, 0x00, 0x46, 0x10, 0x00, 0x00,
		0x42, 0x41, 0x04, 0x1e, 0x18, 0x37, 0xef, 0x0d,
		0x19, 0x51, 0x88, 0x35, 0x75, 0x71, 0xb5, 0xe5,
		0x54, 0x5b, 0x12, 0x2e, 0x8f, 0x09, 0x67, 0xfd,
		0xa7, 0x24, 0x20, 0x3e, 0xb2, 0x56, 0x1c, 0xce,
		0x97, 0x28, 0x5e, 0xf8, 0x2b, 0x2d, 0x4f, 0x9e,
		0xf1, 0x07, 0x9f, 0x6c, 0x4b, 0x5b, 0x83, 0x56,
		0xe2, 0x32, 0x42, 0xe9, 0x58, 0xb6, 0xd7, 0x49,
		0xa6, 0xb5, 0x68, 0x1a, 0x41, 0x03, 0x56, 0x6b,
		0xdc, 0x5a, 0x89, 0x14, 0x03, 0x01, 0x00, 0x01,
		0x01, 0x16, 0x03, 0x01, 0x00, 0x30, 0xd9, 0xa7,
		0x80, 0x56, 0x3f, 0xa3, 0x8f, 0x96, 0x72, 0x4e,
		0x4e, 0x6e, 0x23, 0x41, 0x8f, 0xda, 0x91, 0xb2,
		0x9e, 0x63, 0x23, 0x82, 0x64, 0xcd, 0x07, 0x24,
		0xd3, 0x40, 0x20, 0x22, 0x4c, 0xe3, 0xff, 0x38,
		0xbb, 0x43, 0x9d, 0x57, 0x11, 0xd5, 0x46, 0xa5,
		0x05, 0x29, 0x92, 0x02, 0xce, 0xdf,
	},
	{
		0x14, 0x03, 0x01, 0x00, 0x01, 0x01, 0x16, 0x03,
		0x01, 0x00, 0x90, 0xe7, 0xba, 0x0e, 0xb1, 0xda,
		0x92, 0xb5, 0x77, 0x56, 0x38, 0xa6, 0x22, 0xc1,
		0x72, 0xeb, 0x8a, 0x68, 0x09, 0xb6, 0x74, 0xad,
		0xb3, 0x4a, 0xf2, 0xdd, 0x09, 0x9b, 0xc9, 0x4f,
		0x84, 0x73, 0x8b, 0xd6, 0x97, 0x50, 0x23, 0x1c,
		0xa0, 0xc2, 0x0c, 0x25, 0x18, 0xdd, 0x5e, 0x15,
		0x4d, 0xd9, 0xef, 0x4f, 0x6a, 0x43, 0x61, 0x9c,
		0x95, 0xde, 0x3c, 0x66, 0xc4, 0xc1, 0x33, 0x56,
		0xdd, 0x2f, 0x90, 0xaf, 0x68, 0x5c, 0x9c, 0xa4,
		0x90, 0x6d, 0xbf, 0x51, 0x1d, 0x68, 0xcb, 0x81,
		0x77, 0x52, 0xa0, 0x93, 0x2a, 0xf8, 0xc7, 0x61,
		0x87, 0x76, 0xca, 0x93, 0x9e, 0xd6, 0xee, 0x6f,
		0x3f, 0xeb, 0x7d, 0x06, 0xdd, 0x73, 0x4e, 0x27,
		0x16, 0x63, 0x92, 0xe4, 0xb2, 0x3f, 0x91, 0x23,
		0x21, 0x97, 0x90, 0xce, 0x53, 0xb8, 0xb0, 0x9d,
		0xbd, 0xbd, 0x33, 0x84, 0xad, 0x6b, 0x2e, 0x7b,
		0xf5, 0xeb, 0x1d, 0x64, 0x37, 0x2e, 0x29, 0x4e,
		0xb0, 0x93, 0xdb, 0x92, 0xc7, 0xaa, 0x94, 0xa5,
		0x3b, 0x64, 0xd0,
	},
	{
		0x17, 0x03, 0x01, 0x00, 0x20, 0x11, 0xd8, 0x6b,
		0x3c, 0xf6, 0xbe, 0xf4, 0x54, 0x87, 0xec, 0x75,
		0x0c, 0x44, 0xdb, 0x92, 0xfc, 0xde, 0x7e, 0x0f,
		0x9f, 0x87, 0x87, 0x9c, 0x03, 0xd5, 0x07, 0x84,
		0xe0, 0x3a, 0xf8, 0xae, 0x14, 0x17, 0x03, 0x01,
		0x00, 0x20, 0xba, 0x54, 0xef, 0x5b, 0xce, 0xfd,
		0x47, 0x76, 0x6d, 0xa1, 0x8b, 0xfd, 0x48, 0xde,
		0x6e, 0x26, 0xc1, 0x0c, 0x9d, 0x54, 0xbf, 0x98,
		0xf6, 0x1c, 0x80, 0xb9, 0xca, 0x93, 0x81, 0x0a,
		0x2e, 0x06, 0x15, 0x03, 0x01, 0x00, 0x20, 0x93,
		0x3e, 0x38, 0x17, 0xc9, 0x0a, 0xc3, 0xea, 0xd3,
		0x92, 0x75, 0xa6, 0x53, 0x37, 0x4d, 0x74, 0x94,
		0xbe, 0x01, 0xdc, 0x5c, 0x5a, 0x0f, 0x09, 0xf6,
		0x57, 0x33, 0xc3, 0xbc, 0x3f, 0x7a, 0x4d,
	},
}

var emptyRecordScript = [][]byte{
	{
		0x16, 0x03, 0x01, 0x00, 0x4a, 0x01, 0x00, 0x00,
		0x46, 0x03, 0x01, 0x00, 0x00, 0x00, 0x00, 0x00,
		0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
		0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
		0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
		0x00, 0x00, 0x00, 0x00, 0x00, 0x02, 0x00, 0x35,
		0x01, 0x00, 0x00, 0x1b, 0x00, 0x05, 0x00, 0x05,
		0x01, 0x00, 0x00, 0x00, 0x00, 0x00, 0x0a, 0x00,
		0x08, 0x00, 0x06, 0x00, 0x17, 0x00, 0x18, 0x00,
		0x19, 0x00, 0x0b, 0x00, 0x02, 0x01, 0x00,
	},
	{
		0x16, 0x03, 0x01, 0x00, 0x4a, 0x02, 0x00, 0x00,
		0x46, 0x03, 0x01, 0x51, 0x71, 0x8e, 0x03, 0x02,
		0xef, 0x09, 0xf2, 0x0e, 0xf5, 0x3b, 0x29, 0x9a,
		0xa8, 0x8b, 0x46, 0xa3, 0xd4, 0xb4, 0xc1, 0x14,
		0xc3, 0x19, 0x99, 0xba, 0x3d, 0x78, 0xcf, 0x50,
		0xd1, 0xe7, 0x26, 0x20, 0xa0, 0x37, 0x6d, 0xc9,
		0xae, 0x93, 0x33, 0x81, 0x20, 0xe3, 0xc1, 0x90,
		0x64, 0x6e, 0x67, 0x93, 0xdb, 0xb4, 0x04, 0x16,
		0xc4, 0x25, 0xdd, 0x10, 0x79, 0x3c, 0x18, 0x0a,
		0x7c, 0xfd, 0x28, 0x65, 0x00, 0x35, 0x00, 0x16,
		0x03, 0x01, 0x09, 0x9e, 0x0b, 0x00, 0x09, 0x9a,
		0x00, 0x09, 0x97, 0x00, 0x04, 0xea, 0x30, 0x82,
		0x04, 0xe6, 0x30, 0x82, 0x03, 0xce, 0xa0, 0x03,
		0x02, 0x01, 0x02, 0x02, 0x11, 0x00, 0xff, 0xab,
		0x02, 0x93, 0xe0, 0x72, 0x99, 0x18, 0x6c, 0x9e,
		0x96, 0xb8, 0xb9, 0xf7, 0x47, 0xcb, 0x30, 0x0d,
		0x06, 0x09, 0x2a, 0x86, 0x48, 0x86, 0xf7, 0x0d,
		0x01, 0x01, 0x05, 0x05, 0x00, 0x30, 0x41, 0x31,
		0x0b, 0x30, 0x09, 0x06, 0x03, 0x55, 0x04, 0x06,
		0x13, 0x02, 0x46, 0x52, 0x31, 0x12, 0x30, 0x10,
		0x06, 0x03, 0x55, 0x04, 0x0a, 0x13, 0x09, 0x47,
		0x41, 0x4e, 0x44, 0x49, 0x20, 0x53, 0x41, 0x53,
		0x31, 0x1e, 0x30, 0x1c, 0x06, 0x03, 0x55, 0x04,
		0x03, 0x13, 0x15, 0x47, 0x61, 0x6e, 0x64, 0x69,
		0x20, 0x53, 0x74, 0x61, 0x6e, 0x64, 0x61, 0x72,
		0x64, 0x20, 0x53, 0x53, 0x4c, 0x20, 0x43, 0x41,
		0x30, 0x1e, 0x17, 0x0d, 0x31, 0x33, 0x30, 0x31,
		0x31, 0x34, 0x30, 0x30, 0x30, 0x30, 0x30, 0x30,
		0x5a, 0x17, 0x0d, 0x31, 0x34, 0x30, 0x31, 0x31,
		0x34, 0x32, 0x33, 0x35, 0x39, 0x35, 0x39, 0x5a,
		0x30, 0x62, 0x31, 0x21, 0x30, 0x1f, 0x06, 0x03,
		0x55, 0x04, 0x0b, 0x13, 0x18, 0x44, 0x6f, 0x6d,
		0x61, 0x69, 0x6e, 0x20, 0x43, 0x6f, 0x6e, 0x74,
		0x72, 0x6f, 0x6c, 0x20, 0x56, 0x61, 0x6c, 0x69,
		0x64, 0x61, 0x74, 0x65, 0x64, 0x31, 0x24, 0x30,
		0x22, 0x06, 0x03, 0x55, 0x04, 0x0b, 0x13, 0x1b,
		0x47, 0x61, 0x6e, 0x64, 0x69, 0x20, 0x53, 0x74,
		0x61, 0x6e, 0x64, 0x61, 0x72, 0x64, 0x20, 0x57,
		0x69, 0x6c, 0x64, 0x63, 0x61, 0x72, 0x64, 0x20,
		0x53, 0x53, 0x4c, 0x31, 0x17, 0x30, 0x15, 0x06,
		0x03, 0x55, 0x04, 0x03, 0x14, 0x0e, 0x2a, 0x2e,
		0x66, 0x72, 0x65, 0x65, 0x6e, 0x6f, 0x64, 0x65,
		0x2e, 0x6e, 0x65, 0x74, 0x30, 0x82, 0x01, 0x22,
		0x30, 0x0d, 0x06, 0x09, 0x2a, 0x86, 0x48, 0x86,
		0xf7, 0x0d, 0x01, 0x01, 0x01, 0x05, 0x00, 0x03,
		0x82, 0x01, 0x0f, 0x00, 0x30, 0x82, 0x01, 0x0a,
		0x02, 0x82, 0x01, 0x01, 0x00, 0xdc, 0xe3, 0xfd,
		0xce, 0xc1, 0x66, 0x62, 0x28, 0x8b, 0x99, 0x65,
		0x72, 0x52, 0x88, 0x93, 0x5b, 0x3f, 0x8d, 0xde,
		0x2b, 0xb0, 0xa0, 0xf4, 0xbd, 0xb4, 0x07, 0x5f,
		0x9e, 0x01, 0x47, 0x60, 0x57, 0x5f, 0xdf, 0xdc,
		0x63, 0x28, 0x1c, 0x1e, 0x5b, 0xc8, 0xe6, 0x29,
		0xdd, 0xeb, 0x26, 0x63, 0xd5, 0xbf, 0x83, 0xb2,
		0x2d, 0xcd, 0x2c, 0xa0, 0xb6, 0x91, 0xad, 0xaf,
		0x95, 0x21, 0x1d, 0x1f, 0x39, 0x8d, 0x3e, 0x17,
		0xd6, 0xbd, 0x99, 0xf5, 0x6c, 0xd4, 0xcb, 0x79,
		0x12, 0x3e, 0x11, 0xb9, 0x7e, 0x62, 0xbc, 0x2d,
		0xbf, 0xe0, 0x55, 0x1b, 0x5c, 0x1e, 0xce, 0x31,
		0xd9, 0xf8, 0x56, 0x68, 0x95, 0x2b, 0x15, 0x84,
		0x35, 0xae, 0x98, 0x2c, 0x63, 0x01, 0xb2, 0x0d,
		0xab, 0xa8, 0x61, 0xef, 0x7f, 0x15, 0x2c, 0x6d,
		0xf7, 0x67, 0x1d, 0xb8, 0x8d, 0xf6, 0xa2, 0x1c,
		0x4e, 0x85, 0xf0, 0xea, 0x1a, 0x2b, 0xc8, 0xac,
		0x70, 0x86, 0x9a, 0xbb, 0x9e, 0x9d, 0xbd, 0xc9,
		0x87, 0x2b, 0x9f, 0x5e, 0x40, 0x44, 0x9b, 0xba,
		0x96, 0x45, 0x24, 0xbc, 0x49, 0xb8, 0xfe, 0x26,
		0x3a, 0x1d, 0x1a, 0x0a, 0x3a, 0x90, 0x9c, 0x75,
		0x51, 0x59, 0x89, 0x98, 0x1a, 0x56, 0xe1, 0x3a,
		0x1a, 0xba, 0xff, 0xb4, 0x37, 0x7d, 0xd8, 0x99,
		0xe2, 0xeb, 0x45, 0x27, 0xe2, 0x42, 0x42, 0x46,
		0xbb, 0x00, 0x29, 0x9f, 0x30, 0xc9, 0x1e, 0x6c,
		0xce, 0x59, 0x0e, 0xbe, 0x16, 0x03, 0x31, 0xec,
		0x10, 0xc1, 0x6d, 0xca, 0x9d, 0x5f, 0x6d, 0xf1,
		0x26, 0x11, 0xe5, 0x50, 0xa1, 0xbb, 0x67, 0xb2,
		0xe0, 0x2b, 0xed, 0x76, 0x5b, 0xc7, 0x68, 0xc0,
		0x18, 0xad, 0x91, 0x9e, 0xb5, 0xd4, 0x4d, 0x21,
		0xcd, 0x98, 0xd9, 0xe0, 0x05, 0x0a, 0x4d, 0x24,
		0xa3, 0xe6, 0x12, 0x04, 0xdd, 0x50, 0xe6, 0xc8,
		0x7a, 0x69, 0xb9, 0x32, 0x43, 0x02, 0x03, 0x01,
		0x00, 0x01, 0xa3, 0x82, 0x01, 0xb6, 0x30, 0x82,
		0x01, 0xb2, 0x30, 0x1f, 0x06, 0x03, 0x55, 0x1d,
		0x23, 0x04, 0x18, 0x30, 0x16, 0x80, 0x14, 0xb6,
		0xa8, 0xff, 0xa2, 0xa8, 0x2f, 0xd0, 0xa6, 0xcd,
		0x4b, 0xb1, 0x68, 0xf3, 0xe7, 0x50, 0x10, 0x31,
		0xa7, 0x79, 0x21, 0x30, 0x1d, 0x06, 0x03, 0x55,
		0x1d, 0x0e, 0x04, 0x16, 0x04, 0x14, 0x62, 0x37,
		0xd4, 0x3c, 0xbf, 0xd9, 0xc2, 0x99, 0xf3, 0x28,
		0x3e, 0xdb, 0xca, 0xee, 0xf3, 0xb3, 0xc8, 0x73,
		0xb0, 0x3c, 0x30, 0x0e, 0x06, 0x03, 0x55, 0x1d,
		0x0f, 0x01, 0x01, 0xff, 0x04, 0x04, 0x03, 0x02,
		0x05, 0xa0, 0x30, 0x0c, 0x06, 0x03, 0x55, 0x1d,
		0x13, 0x01, 0x01, 0xff, 0x04, 0x02, 0x30, 0x00,
		0x30, 0x1d, 0x06, 0x03, 0x55, 0x1d, 0x25, 0x04,
		0x16, 0x30, 0x14, 0x06, 0x08, 0x2b, 0x06, 0x01,
		0x05, 0x05, 0x07, 0x03, 0x01, 0x06, 0x08, 0x2b,
		0x06, 0x01, 0x05, 0x05, 0x07, 0x03, 0x02, 0x30,
		0x60, 0x06, 0x03, 0x55, 0x1d, 0x20, 0x04, 0x59,
		0x30, 0x57, 0x30, 0x4b, 0x06, 0x0b, 0x2b, 0x06,
		0x01, 0x04, 0x01, 0xb2, 0x31, 0x01, 0x02, 0x02,
		0x1a, 0x30, 0x3c, 0x30, 0x3a, 0x06, 0x08, 0x2b,
		0x06, 0x01, 0x05, 0x05, 0x07, 0x02, 0x01, 0x16,
		0x2e, 0x68, 0x74, 0x74, 0x70, 0x3a, 0x2f, 0x2f,
		0x77, 0x77, 0x77, 0x2e, 0x67, 0x61, 0x6e, 0x64,
		0x69, 0x2e, 0x6e, 0x65, 0x74, 0x2f, 0x63, 0x6f,
		0x6e, 0x74, 0x72, 0x61, 0x63, 0x74, 0x73, 0x2f,
		0x66, 0x72, 0x2f, 0x73, 0x73, 0x6c, 0x2f, 0x63,
		0x70, 0x73, 0x2f, 0x70, 0x64, 0x66, 0x2f, 0x30,
		0x08, 0x06, 0x06, 0x67, 0x81, 0x0c, 0x01, 0x02,
		0x01, 0x30, 0x3c, 0x06, 0x03, 0x55, 0x1d, 0x1f,
		0x04, 0x35, 0x30, 0x33, 0x30, 0x31, 0xa0, 0x2f,
		0xa0, 0x2d, 0x86, 0x2b, 0x68, 0x74, 0x74, 0x70,
		0x3a, 0x2f, 0x2f, 0x63, 0x72, 0x6c, 0x2e, 0x67,
		0x61, 0x6e, 0x64, 0x69, 0x2e, 0x6e, 0x65, 0x74,
		0x2f, 0x47, 0x61, 0x6e, 0x64, 0x69, 0x53, 0x74,
		0x61, 0x6e, 0x64, 0x61, 0x72, 0x64, 0x53, 0x53,
		0x4c, 0x43, 0x41, 0x2e, 0x63, 0x72, 0x6c, 0x30,
		0x6a, 0x06, 0x08, 0x2b, 0x06, 0x01, 0x05, 0x05,
		0x07, 0x01, 0x01, 0x04, 0x5e, 0x30, 0x5c, 0x30,
		0x37, 0x06, 0x08, 0x2b, 0x06, 0x01, 0x05, 0x05,
		0x07, 0x30, 0x02, 0x86, 0x2b, 0x68, 0x74, 0x74,
		0x70, 0x3a, 0x2f, 0x2f, 0x63, 0x72, 0x74, 0x2e,
		0x67, 0x61, 0x6e, 0x64, 0x69, 0x2e, 0x6e, 0x65,
		0x74, 0x2f, 0x47, 0x61, 0x6e, 0x64, 0x69, 0x53,
		0x74, 0x61, 0x6e, 0x64, 0x61, 0x72, 0x64, 0x53,
		0x53, 0x4c, 0x43, 0x41, 0x2e, 0x63, 0x72, 0x74,
		0x30, 0x21, 0x06, 0x08, 0x2b, 0x06, 0x01, 0x05,
		0x05, 0x07, 0x30, 0x01, 0x86, 0x15, 0x68, 0x74,
		0x74, 0x70, 0x3a, 0x2f, 0x2f, 0x6f, 0x63, 0x73,
		0x70, 0x2e, 0x67, 0x61, 0x6e, 0x64, 0x69, 0x2e,
		0x6e, 0x65, 0x74, 0x30, 0x27, 0x06, 0x03, 0x55,
		0x1d, 0x11, 0x04, 0x20, 0x30, 0x1e, 0x82, 0x0e,
		0x2a, 0x2e, 0x66, 0x72, 0x65, 0x65, 0x6e, 0x6f,
		0x64, 0x65, 0x2e, 0x6e, 0x65, 0x74, 0x82, 0x0c,
		0x66, 0x72, 0x65, 0x65, 0x6e, 0x6f, 0x64, 0x65,
		0x2e, 0x6e, 0x65, 0x74, 0x30, 0x0d, 0x06, 0x09,
		0x2a, 0x86, 0x48, 0x86, 0xf7, 0x0d, 0x01, 0x01,
		0x05, 0x05, 0x00, 0x03, 0x82, 0x01, 0x01, 0x00,
		0x5b, 0x4a, 0x3a, 0x1d, 0x75, 0xe0, 0xc0, 0x9e,
		0xc9, 0x16, 0x66, 0x7f, 0x73, 0x95, 0x6e, 0x35,
		0xe4, 0x27, 0xfa, 0x8c, 0x9d, 0xee, 0xb1, 0x37,
		0x42, 0x3f, 0x54, 0x6a, 0x9d, 0x41, 0x84, 0x57,
		0xe1, 0x03, 0x3d, 0x69, 0x61, 0x77, 0x3b, 0x91,
		0xa2, 0x70, 0x94, 0xb6, 0x8e, 0x41, 0x63, 0x70,
		0xf2, 0x16, 0x04, 0x50, 0x05, 0x14, 0xfb, 0x59,
		0x7d, 0x89, 0x09, 0x3f, 0xb6, 0xef, 0xca, 0x3c,
		0x89, 0x88, 0x08, 0xe9, 0xa1, 0xf3, 0x33, 0x31,
		0x05, 0x4d, 0x70, 0xff, 0xdd, 0xa7, 0xd2, 0xe2,
		0xa0, 0x94, 0x3a, 0xf7, 0xc2, 0x9f, 0xad, 0x2b,
		0x2e, 0x20, 0xfa, 0x6c, 0xe1, 0xfc, 0xe6, 0x62,
		0x22, 0xa1, 0x38, 0x93, 0xec, 0x3e, 0xce, 0xfd,
		0x1f, 0xdd, 0xd4, 0x7c, 0x39, 0x46, 0x8b, 0xb4,
		0x64, 0xfa, 0xa1, 0x46, 0x87, 0x78, 0x2c, 0xd7,
		0x9c, 0xdd, 0x60, 0xd6, 0xda, 0x8e, 0xd8, 0x29,
		0x6d, 0x61, 0xa7, 0x29, 0x07, 0x76, 0xfc, 0xf9,
		0xbd, 0xfd, 0x14, 0xeb, 0x44, 0x70, 0xff, 0xd0,
		0x23, 0x99, 0x83, 0xc5, 0x5c, 0x56, 0x88, 0xaa,
		0x34, 0xda, 0xa6, 0xb3, 0x9a, 0xbf, 0xda, 0x58,
		0x1e, 0xa4, 0xb8, 0xc0, 0x40, 0x9d, 0xf0, 0xfc,
		0xf1, 0x23, 0xc2, 0xbc, 0x59, 0xe1, 0x82, 0xed,
		0x5d, 0xfb, 0x99, 0xaf, 0xf5, 0xf5, 0x15, 0xb8,
		0x8b, 0x59, 0xce, 0xaa, 0xca, 0xdf, 0xdc, 0x94,
		0x11, 0xe0, 0x96, 0xbf, 0x9f, 0x54, 0xa4, 0x9f,
		0x54, 0x36, 0x4a, 0xe8, 0x93, 0xda, 0xf4, 0x8c,
		0xb0, 0x6b, 0x8d, 0x4a, 0x9e, 0x11, 0xae, 0xcb,
		0xcb, 0x33, 0x8a, 0x4d, 0xcd, 0x4e, 0xa5, 0x9b,
		0xe9, 0x14, 0x46, 0x43, 0x9b, 0x96, 0x5f, 0x6d,
		0xf2, 0xea, 0x40, 0xef, 0x14, 0xc3, 0x99, 0x9f,
		0x23, 0x1e, 0xa5, 0x13, 0xab, 0x08, 0xea, 0x8f,
		0x68, 0x5b, 0x7d, 0x71, 0xdf, 0x18, 0xd1, 0x57,
		0x00, 0x04, 0xa7, 0x30, 0x82, 0x04, 0xa3, 0x30,
		0x82, 0x03, 0x8b, 0xa0, 0x03, 0x02, 0x01, 0x02,
		0x02, 0x10, 0x5a, 0xb6, 0x1d, 0xac, 0x1e, 0x4d,
		0xa2, 0x06, 0x14, 0xc7, 0x55, 0x3d, 0x3d, 0xa9,
		0xb2, 0xdc, 0x30, 0x0d, 0x06, 0x09, 0x2a, 0x86,
		0x48, 0x86, 0xf7, 0x0d, 0x01, 0x01, 0x05, 0x05,
		0x00, 0x30, 0x81, 0x97, 0x31, 0x0b, 0x30, 0x09,
		0x06, 0x03, 0x55, 0x04, 0x06, 0x13, 0x02, 0x55,
		0x53, 0x31, 0x0b, 0x30, 0x09, 0x06, 0x03, 0x55,
		0x04, 0x08, 0x13, 0x02, 0x55, 0x54, 0x31, 0x17,
		0x30, 0x15, 0x06, 0x03, 0x55, 0x04, 0x07, 0x13,
		0x0e, 0x53, 0x61, 0x6c, 0x74, 0x20, 0x4c, 0x61,
		0x6b, 0x65, 0x20, 0x43, 0x69, 0x74, 0x79, 0x31,
		0x1e, 0x30, 0x1c, 0x06, 0x03, 0x55, 0x04, 0x0a,
		0x13, 0x15, 0x54, 0x68, 0x65, 0x20, 0x55, 0x53,
		0x45, 0x52, 0x54, 0x52, 0x55, 0x53, 0x54, 0x20,
		0x4e, 0x65, 0x74, 0x77, 0x6f, 0x72, 0x6b, 0x31,
		0x21, 0x30, 0x1f, 0x06, 0x03, 0x55, 0x04, 0x0b,
		0x13, 0x18, 0x68, 0x74, 0x74, 0x70, 0x3a, 0x2f,
		0x2f, 0x77, 0x77, 0x77, 0x2e, 0x75, 0x73, 0x65,
		0x72, 0x74, 0x72, 0x75, 0x73, 0x74, 0x2e, 0x63,
		0x6f, 0x6d, 0x31, 0x1f, 0x30, 0x1d, 0x06, 0x03,
		0x55, 0x04, 0x03, 0x13, 0x16, 0x55, 0x54, 0x4e,
		0x2d, 0x55, 0x53, 0x45, 0x52, 0x46, 0x69, 0x72,
		0x73, 0x74, 0x2d, 0x48, 0x61, 0x72, 0x64, 0x77,
		0x61, 0x72, 0x65, 0x30, 0x1e, 0x17, 0x0d, 0x30,
		0x38, 0x31, 0x30, 0x32, 0x33, 0x30, 0x30, 0x30,
		0x30, 0x30, 0x30, 0x5a, 0x17, 0x0d, 0x32, 0x30,
		0x30, 0x35, 0x33, 0x30, 0x31, 0x30, 0x34, 0x38,
		0x33, 0x38, 0x5a, 0x30, 0x41, 0x31, 0x0b, 0x30,
		0x09, 0x06, 0x03, 0x55, 0x04, 0x06, 0x13, 0x02,
		0x46, 0x52, 0x31, 0x12, 0x30, 0x10, 0x06, 0x03,
		0x55, 0x04, 0x0a, 0x13, 0x09, 0x47, 0x41, 0x4e,
		0x44, 0x49, 0x20, 0x53, 0x41, 0x53, 0x31, 0x1e,
		0x30, 0x1c, 0x06, 0x03, 0x55, 0x04, 0x03, 0x13,
		0x15, 0x47, 0x61, 0x6e, 0x64, 0x69, 0x20, 0x53,
		0x74, 0x61, 0x6e, 0x64, 0x61, 0x72, 0x64, 0x20,
		0x53, 0x53, 0x4c, 0x20, 0x43, 0x41, 0x30, 0x82,
		0x01, 0x22, 0x30, 0x0d, 0x06, 0x09, 0x2a, 0x86,
		0x48, 0x86, 0xf7, 0x0d, 0x01, 0x01, 0x01, 0x05,
		0x00, 0x03, 0x82, 0x01, 0x0f, 0x00, 0x30, 0x82,
		0x01, 0x0a, 0x02, 0x82, 0x01, 0x01, 0x00, 0xb6,
		0x54, 0x3d, 0xa5, 0xdb, 0x0d, 0x22, 0x78, 0x50,
		0x6a, 0x5a, 0x23, 0x89, 0x3f, 0x97, 0xa1, 0xd4,
		0x07, 0x1a, 0xa9, 0x58, 0x08, 0x9b, 0xa0, 0x15,
		0xc3, 0x32, 0xb6, 0xb7, 0xf1, 0xe8, 0xb9, 0xa5,
		0x6f, 0xad, 0x37, 0xf6, 0x6e, 0x71, 0x1b, 0xb4,
		0x75, 0x2d, 0x48, 0x5e, 0x9f, 0xc6, 0x15, 0xaa,
		0x81, 0xef, 0xe5, 0xc4, 0x88, 0x95, 0x8a, 0x3a,
		0x6c, 0x77, 0xcc, 0xb5, 0xcd, 0x65, 0xe4, 0x67,
		0xe5, 0x73, 0xc9, 0x50, 0x52, 0x94, 0xc1, 0x27,
		0x49, 0x3e, 0xa0, 0x6b, 0x41, 0x16, 0x41, 0xb6,
		0x94, 0x99, 0x41, 0xae, 0x3e, 0xcb, 0xe2, 0x06,
		0x46, 0x09, 0xe9, 0x4d, 0xbe, 0xc9, 0x4c, 0x55,
		0xa9, 0x18, 0x7e, 0xa6, 0xdf, 0x6e, 0xfd, 0x4a,
		0xb2, 0xcc, 0x6c, 0x4e, 0xd9, 0xc8, 0x50, 0x15,
		0x93, 0xb3, 0xf2, 0xe9, 0xe3, 0xc2, 0x6a, 0xad,
		0x3a, 0xd5, 0xfb, 0xc3, 0x79, 0x50, 0x9f, 0x25,
		0x79, 0x29, 0xb2, 0x47, 0x64, 0x7c, 0x20, 0x3e,
		0xe2, 0x08, 0x4d, 0x93, 0x29, 0x14, 0xb6, 0x34,
		0x6e, 0xcf, 0x71, 0x46, 0x7e, 0x76, 0x10, 0xf4,
		0xfd, 0x6c, 0xaa, 0x01, 0xd2, 0xc2, 0x06, 0xde,
		0x92, 0x83, 0xcc, 0x58, 0x90, 0x2e, 0x92, 0xde,
		0x1e, 0x65, 0xb7, 0x63, 0x2f, 0x3d, 0xb2, 0xeb,
		0x70, 0x8c, 0x4c, 0xe0, 0xbe, 0x15, 0x9d, 0xde,
		0xc1, 0x4d, 0x56, 0xf8, 0x0b, 0xc6, 0x8e, 0x07,
		0xb9, 0x5d, 0xdf, 0x95, 0xf0, 0x7b, 0x40, 0x1f,
		0x1a, 0x2c, 0xd7, 0x9c, 0x2b, 0x4b, 0x76, 0xf4,
		0x59, 0xf5, 0x43, 0xc1, 0x2c, 0x66, 0x10, 0x9e,
		0x9e, 0x66, 0x96, 0x60, 0x9d, 0x1c, 0x74, 0x1b,
		0x4e, 0x18, 0x5c, 0x08, 0xb0, 0x6e, 0x6c, 0xca,
		0x69, 0x1a, 0x02, 0xe9, 0xbb, 0xca, 0x78, 0xef,
		0x66, 0x2e, 0xe3, 0x32, 0xfd, 0x41, 0x5c, 0x95,
		0x74, 0x81, 0x4d, 0xf4, 0xda, 0xfe, 0x4b, 0x02,
		0x03, 0x01, 0x00, 0x01, 0xa3, 0x82, 0x01, 0x3e,
		0x30, 0x82, 0x01, 0x3a, 0x30, 0x1f, 0x06, 0x03,
		0x55, 0x1d, 0x23, 0x04, 0x18, 0x30, 0x16, 0x80,
		0x14, 0xa1, 0x72, 0x5f, 0x26, 0x1b, 0x28, 0x98,
		0x43, 0x95, 0x5d, 0x07, 0x37, 0xd5, 0x85, 0x96,
		0x9d, 0x4b, 0xd2, 0xc3, 0x45, 0x30, 0x1d, 0x06,
		0x03, 0x55, 0x1d, 0x0e, 0x04, 0x16, 0x04, 0x14,
		0xb6, 0xa8, 0xff, 0xa2, 0xa8, 0x2f, 0xd0, 0xa6,
		0xcd, 0x4b, 0xb1, 0x68, 0xf3, 0xe7, 0x50, 0x10,
		0x31, 0xa7, 0x79, 0x21, 0x30, 0x0e, 0x06, 0x03,
		0x55, 0x1d, 0x0f, 0x01, 0x01, 0xff, 0x04, 0x04,
		0x03, 0x02, 0x01, 0x06, 0x30, 0x12, 0x06, 0x03,
		0x55, 0x1d, 0x13, 0x01, 0x01, 0xff, 0x04, 0x08,
		0x30, 0x06, 0x01, 0x01, 0xff, 0x02, 0x01, 0x00,
		0x30, 0x18, 0x06, 0x03, 0x55, 0x1d, 0x20, 0x04,
		0x11, 0x30, 0x0f, 0x30, 0x0d, 0x06, 0x0b, 0x2b,
		0x06, 0x01, 0x04, 0x01, 0xb2, 0x31, 0x01, 0x02,
		0x02, 0x1a, 0x30, 0x44, 0x06, 0x03, 0x55, 0x1d,
		0x1f, 0x04, 0x3d, 0x30, 0x3b, 0x30, 0x39, 0xa0,
		0x37, 0xa0, 0x35, 0x86, 0x33, 0x68, 0x74, 0x74,
		0x70, 0x3a, 0x2f, 0x2f, 0x63, 0x72, 0x6c, 0x2e,
		0x75, 0x73, 0x65, 0x72, 0x74, 0x72, 0x75, 0x73,
		0x74, 0x2e, 0x63, 0x6f, 0x6d, 0x2f, 0x55, 0x54,
		0x4e, 0x2d, 0x55, 0x53, 0x45, 0x52, 0x46, 0x69,
		0x72, 0x73, 0x74, 0x2d, 0x48, 0x61, 0x72, 0x64,
		0x77, 0x61, 0x72, 0x65, 0x2e, 0x63, 0x72, 0x6c,
		0x30, 0x74, 0x06, 0x08, 0x2b, 0x06, 0x01, 0x05,
		0x05, 0x07, 0x01, 0x01, 0x04, 0x68, 0x30, 0x66,
		0x30, 0x3d, 0x06, 0x08, 0x2b, 0x06, 0x01, 0x05,
		0x05, 0x07, 0x30, 0x02, 0x86, 0x31, 0x68, 0x74,
		0x74, 0x70, 0x3a, 0x2f, 0x2f, 0x63, 0x72, 0x74,
		0x2e, 0x75, 0x73, 0x65, 0x72, 0x74, 0x72, 0x75,
		0x73, 0x74, 0x2e, 0x63, 0x6f, 0x6d, 0x2f, 0x55,
		0x54, 0x4e, 0x41, 0x64, 0x64, 0x54, 0x72, 0x75,
		0x73, 0x74, 0x53, 0x65, 0x72, 0x76, 0x65, 0x72,
		0x5f, 0x43, 0x41, 0x2e, 0x63, 0x72, 0x74, 0x30,
		0x25, 0x06, 0x08, 0x2b, 0x06, 0x01, 0x05, 0x05,
		0x07, 0x30, 0x01, 0x86, 0x19, 0x68, 0x74, 0x74,
		0x70, 0x3a, 0x2f, 0x2f, 0x6f, 0x63, 0x73, 0x70,
		0x2e, 0x75, 0x73, 0x65, 0x72, 0x74, 0x72, 0x75,
		0x73, 0x74, 0x2e, 0x63, 0x6f, 0x6d, 0x30, 0x0d,
		0x06, 0x09, 0x2a, 0x86, 0x48, 0x86, 0xf7, 0x0d,
		0x01, 0x01, 0x05, 0x05, 0x00, 0x03, 0x82, 0x01,
		0x01, 0x00, 0x19, 0x53, 0xbf, 0x03, 0x3d, 0x9b,
		0xe2, 0x6b, 0x5a, 0xfd, 0xba, 0x49, 0x1f, 0x4f,
		0xec, 0xe1, 0xc6, 0x82, 0x39, 0x3c, 0xd2, 0x03,
		0x04, 0x0f, 0xab, 0x7b, 0x3e, 0x82, 0xa9, 0x85,
		0x10, 0x1f, 0xf4, 0xde, 0x32, 0xaf, 0x58, 0x3f,
		0xff, 0x70, 0xf3, 0x30, 0x1d, 0x97, 0x2d, 0x4c,
		0x9a, 0xe2, 0xec, 0x0c, 0x3e, 0x14, 0x2d, 0x2f,
		0x98, 0x48, 0x9d, 0xae, 0x16, 0x6a, 0xac, 0x2d,
		0x42, 0xaa, 0xb5, 0x64, 0xa4, 0x70, 0xbb, 0xeb,
		0x73, 0x94, 0x7b, 0x46, 0x4c, 0xe7, 0x7a, 0x14,
		0x76, 0x5b, 0x4c, 0x1d, 0x84, 0xa1, 0x20, 0x74,
		0x1f, 0x2e, 0x4b, 0x5c, 0x70, 0x88, 0xdc, 0xbd,
		0xf7, 0x19, 0x3d, 0xed, 0x59, 0x0d, 0xe2, 0x3f,
		0x26, 0xe2, 0x9c, 0xac, 0xa4, 0x3c, 0x95, 0x1c,
		0xf8, 0xbe, 0x8c, 0x03, 0xae, 0xf0, 0xe5, 0x9c,
		0x4d, 0xbc, 0xc7, 0x9b, 0x58, 0x00, 0xbf, 0xaf,
		0xad, 0xfa, 0x37, 0x6e, 0x71, 0x6d, 0x18, 0x34,
		0x0e, 0xc1, 0xea, 0x6a, 0xf8, 0x0d, 0xdf, 0x69,
		0x54, 0x56, 0x15, 0xf2, 0x28, 0xb3, 0xfe, 0xa4,
		0x63, 0xec, 0xc5, 0x04, 0x64, 0x60, 0xbb, 0xfe,
		0x2a, 0xf0, 0xf4, 0x87, 0xa1, 0xb0, 0xae, 0xbd,
		0xaa, 0xe4, 0x2f, 0xe3, 0x03, 0x0b, 0x2f, 0x66,
		0x5f, 0x85, 0xa4, 0x32, 0x7b, 0x46, 0xed, 0x25,
		0x0c, 0xe7, 0xf1, 0xb7, 0xe7, 0x19, 0xfd, 0x60,
		0xba, 0x5f, 0x87, 0x77, 0xde, 0x98, 0x07, 0x96,
		0xe4, 0x5e, 0xea, 0x63, 0x7d, 0xa8, 0xde, 0x55,
		0xda, 0x61, 0x5c, 0x3c, 0x90, 0x83, 0x43, 0x04,
		0x07, 0x3c, 0xdd, 0xf3, 0xf8, 0x9f, 0x06, 0x52,
		0x0a, 0xde, 0xc7, 0xb6, 0x7b, 0x8f, 0xe1, 0x11,
		0xf7, 0x04, 0x7a, 0x35, 0xff, 0x6a, 0xbc, 0x5b,
		0xc7, 0x50, 0x49, 0x08, 0x70, 0x6f, 0x94, 0x43,
		0xcd, 0x9e, 0xc7, 0x70, 0xf1, 0xdb, 0xd0, 0x6d,
		0xda, 0x8f, 0x16, 0x03, 0x01, 0x00, 0x0e, 0x0d,
		0x00, 0x00, 0x06, 0x03, 0x01, 0x02, 0x40, 0x00,
		0x00, 0x0e, 0x00, 0x00, 0x00,
	},
	{
		0x16, 0x03, 0x01, 0x02, 0xbe, 0x0b, 0x00, 0x02,
		0xba, 0x00, 0x02, 0xb7, 0x00, 0x02, 0xb4, 0x30,
		0x82, 0x02, 0xb0, 0x30, 0x82, 0x02, 0x19, 0xa0,
		0x03, 0x02, 0x01, 0x02, 0x02, 0x09, 0x00, 0x85,
		0xb0, 0xbb, 0xa4, 0x8a, 0x7f, 0xb8, 0xca, 0x30,
		0x0d, 0x06, 0x09, 0x2a, 0x86, 0x48, 0x86, 0xf7,
		0x0d, 0x01, 0x01, 0x05, 0x05, 0x00, 0x30, 0x45,
		0x31, 0x0b, 0x30, 0x09, 0x06, 0x03, 0x55, 0x04,
		0x06, 0x13, 0x02, 0x41, 0x55, 0x31, 0x13, 0x30,
		0x11, 0x06, 0x03, 0x55, 0x04, 0x08, 0x13, 0x0a,
		0x53, 0x6f, 0x6d, 0x65, 0x2d, 0x53, 0x74, 0x61,
		0x74, 0x65, 0x31, 0x21, 0x30, 0x1f, 0x06, 0x03,
		0x55, 0x04, 0x0a, 0x13, 0x18, 0x49, 0x6e, 0x74,
		0x65, 0x72, 0x6e, 0x65, 0x74, 0x20, 0x57, 0x69,
		0x64, 0x67, 0x69, 0x74, 0x73, 0x20, 0x50, 0x74,
		0x79, 0x20, 0x4c, 0x74, 0x64, 0x30, 0x1e, 0x17,
		0x0d, 0x31, 0x30, 0x30, 0x34, 0x32, 0x34, 0x30,
		0x39, 0x30, 0x39, 0x33, 0x38, 0x5a, 0x17, 0x0d,
		0x31, 0x31, 0x30, 0x34, 0x32, 0x34, 0x30, 0x39,
		0x30, 0x39, 0x33, 0x38, 0x5a, 0x30, 0x45, 0x31,
		0x0b, 0x30, 0x09, 0x06, 0x03, 0x55, 0x04, 0x06,
		0x13, 0x02, 0x41, 0x55, 0x31, 0x13, 0x30, 0x11,
		0x06, 0x03, 0x55, 0x04, 0x08, 0x13, 0x0a, 0x53,
		0x6f, 0x6d, 0x65, 0x2d, 0x53, 0x74, 0x61, 0x74,
		0x65, 0x31, 0x21, 0x30, 0x1f, 0x06, 0x03, 0x55,
		0x04, 0x0a, 0x13, 0x18, 0x49, 0x6e, 0x74, 0x65,
		0x72, 0x6e, 0x65, 0x74, 0x20, 0x57, 0x69, 0x64,
		0x67, 0x69, 0x74, 0x73, 0x20, 0x50, 0x74, 0x79,
		0x20, 0x4c, 0x74, 0x64, 0x30, 0x81, 0x9f, 0x30,
		0x0d, 0x06, 0x09, 0x2a, 0x86, 0x48, 0x86, 0xf7,
		0x0d, 0x01, 0x01, 0x01, 0x05, 0x00, 0x03, 0x81,
		0x8d, 0x00, 0x30, 0x81, 0x89, 0x02, 0x81, 0x81,
		0x00, 0xbb, 0x79, 0xd6, 0xf5, 0x17, 0xb5, 0xe5,
		0xbf, 0x46, 0x10, 0xd0, 0xdc, 0x69, 0xbe, 0xe6,
		0x2b, 0x07, 0x43, 0x5a, 0xd0, 0x03, 0x2d, 0x8a,
		0x7a, 0x43, 0x85, 0xb7, 0x14, 0x52, 0xe7, 0xa5,
		0x65, 0x4c, 0x2c, 0x78, 0xb8, 0x23, 0x8c, 0xb5,
		0xb4, 0x82, 0xe5, 0xde, 0x1f, 0x95, 0x3b, 0x7e,
		0x62, 0xa5, 0x2c, 0xa5, 0x33, 0xd6, 0xfe, 0x12,
		0x5c, 0x7a, 0x56, 0xfc, 0xf5, 0x06, 0xbf, 0xfa,
		0x58, 0x7b, 0x26, 0x3f, 0xb5, 0xcd, 0x04, 0xd3,
		0xd0, 0xc9, 0x21, 0x96, 0x4a, 0xc7, 0xf4, 0x54,
		0x9f, 0x5a, 0xbf, 0xef, 0x42, 0x71, 0x00, 0xfe,
		0x18, 0x99, 0x07, 0x7f, 0x7e, 0x88, 0x7d, 0x7d,
		0xf1, 0x04, 0x39, 0xc4, 0xa2, 0x2e, 0xdb, 0x51,
		0xc9, 0x7c, 0xe3, 0xc0, 0x4c, 0x3b, 0x32, 0x66,
		0x01, 0xcf, 0xaf, 0xb1, 0x1d, 0xb8, 0x71, 0x9a,
		0x1d, 0xdb, 0xdb, 0x89, 0x6b, 0xae, 0xda, 0x2d,
		0x79, 0x02, 0x03, 0x01, 0x00, 0x01, 0xa3, 0x81,
		0xa7, 0x30, 0x81, 0xa4, 0x30, 0x1d, 0x06, 0x03,
		0x55, 0x1d, 0x0e, 0x04, 0x16, 0x04, 0x14, 0xb1,
		0xad, 0xe2, 0x85, 0x5a, 0xcf, 0xcb, 0x28, 0xdb,
		0x69, 0xce, 0x23, 0x69, 0xde, 0xd3, 0x26, 0x8e,
		0x18, 0x88, 0x39, 0x30, 0x75, 0x06, 0x03, 0x55,
		0x1d, 0x23, 0x04, 0x6e, 0x30, 0x6c, 0x80, 0x14,
		0xb1, 0xad, 0xe2, 0x85, 0x5a, 0xcf, 0xcb, 0x28,
		0xdb, 0x69, 0xce, 0x23, 0x69, 0xde, 0xd3, 0x26,
		0x8e, 0x18, 0x88, 0x39, 0xa1, 0x49, 0xa4, 0x47,
		0x30, 0x45, 0x31, 0x0b, 0x30, 0x09, 0x06, 0x03,
		0x55, 0x04, 0x06, 0x13, 0x02, 0x41, 0x55, 0x31,
		0x13, 0x30, 0x11, 0x06, 0x03, 0x55, 0x04, 0x08,
		0x13, 0x0a, 0x53, 0x6f, 0x6d, 0x65, 0x2d, 0x53,
		0x74, 0x61, 0x74, 0x65, 0x31, 0x21, 0x30, 0x1f,
		0x06, 0x03, 0x55, 0x04, 0x0a, 0x13, 0x18, 0x49,
		0x6e, 0x74, 0x65, 0x72, 0x6e, 0x65, 0x74, 0x20,
		0x57, 0x69, 0x64, 0x67, 0x69, 0x74, 0x73, 0x20,
		0x50, 0x74, 0x79, 0x20, 0x4c, 0x74, 0x64, 0x82,
		0x09, 0x00, 0x85, 0xb0, 0xbb, 0xa4, 0x8a, 0x7f,
		0xb8, 0xca, 0x30, 0x0c, 0x06, 0x03, 0x55, 0x1d,
		0x13, 0x04, 0x05, 0x30, 0x03, 0x01, 0x01, 0xff,
		0x30, 0x0d, 0x06, 0x09, 0x2a, 0x86, 0x48, 0x86,
		0xf7, 0x0d, 0x01, 0x01, 0x05, 0x05, 0x00, 0x03,
		0x81, 0x81, 0x00, 0x08, 0x6c, 0x45, 0x24, 0xc7,
		0x6b, 0xb1, 0x59, 0xab, 0x0c, 0x52, 0xcc, 0xf2,
		0xb0, 0x14, 0xd7, 0x87, 0x9d, 0x7a, 0x64, 0x75,
		0xb5, 0x5a, 0x95, 0x66, 0xe4, 0xc5, 0x2b, 0x8e,
		0xae, 0x12, 0x66, 0x1f, 0xeb, 0x4f, 0x38, 0xb3,
		0x6e, 0x60, 0xd3, 0x92, 0xfd, 0xf7, 0x41, 0x08,
		0xb5, 0x25, 0x13, 0xb1, 0x18, 0x7a, 0x24, 0xfb,
		0x30, 0x1d, 0xba, 0xed, 0x98, 0xb9, 0x17, 0xec,
		0xe7, 0xd7, 0x31, 0x59, 0xdb, 0x95, 0xd3, 0x1d,
		0x78, 0xea, 0x50, 0x56, 0x5c, 0xd5, 0x82, 0x5a,
		0x2d, 0x5a, 0x5f, 0x33, 0xc4, 0xb6, 0xd8, 0xc9,
		0x75, 0x90, 0x96, 0x8c, 0x0f, 0x52, 0x98, 0xb5,
		0xcd, 0x98, 0x1f, 0x89, 0x20, 0x5f, 0xf2, 0xa0,
		0x1c, 0xa3, 0x1b, 0x96, 0x94, 0xdd, 0xa9, 0xfd,
		0x57, 0xe9, 0x70, 0xe8, 0x26, 0x6d, 0x71, 0x99,
		0x9b, 0x26, 0x6e, 0x38, 0x50, 0x29, 0x6c, 0x90,
		0xa7, 0xbd, 0xd9, 0x16, 0x03, 0x01, 0x01, 0x06,
		0x10, 0x00, 0x01, 0x02, 0x01, 0x00, 0x25, 0x48,
		0x6c, 0x0a, 0xde, 0x9d, 0x3a, 0x57, 0xe4, 0x2e,
		0xb9, 0xfc, 0xb4, 0x46, 0x1f, 0x20, 0x4f, 0x58,
		0x4d, 0x12, 0x08, 0xb4, 0x3e, 0x4c, 0xf5, 0xa8,
		0xa5, 0x16, 0x40, 0x29, 0x19, 0x04, 0x4d, 0xf9,
		0x54, 0x3a, 0x32, 0xd7, 0x79, 0xf2, 0x0e, 0xc1,
		0x7b, 0x0c, 0x62, 0x71, 0xbb, 0xb4, 0x8c, 0xe7,
		0x84, 0xd5, 0xf8, 0x11, 0x77, 0x7f, 0x87, 0x6c,
		0xfc, 0x25, 0xf3, 0x2d, 0x97, 0x3d, 0x1f, 0xf5,
		0xfc, 0x64, 0x94, 0x9f, 0xdd, 0x90, 0x82, 0xdd,
		0x11, 0x74, 0x74, 0x59, 0xa2, 0x1a, 0x71, 0xb2,
		0x55, 0x6d, 0x18, 0xca, 0x85, 0x47, 0x8b, 0x79,
		0x73, 0x06, 0x24, 0x38, 0xc3, 0x34, 0x98, 0x84,
		0x62, 0x81, 0xd8, 0xad, 0x54, 0xad, 0x13, 0xa5,
		0xf4, 0xe4, 0x82, 0x85, 0xd3, 0xe3, 0x9e, 0xeb,
		0xb5, 0xf5, 0x95, 0x83, 0x0e, 0xb9, 0x7d, 0xb6,
		0xda, 0x0c, 0xf6, 0x14, 0x6a, 0x60, 0x8c, 0x75,
		0x56, 0xf0, 0xe9, 0x60, 0xe0, 0x4c, 0xf4, 0x4e,
		0x84, 0x8b, 0x4f, 0xf4, 0x2f, 0xde, 0xb7, 0xec,
		0x61, 0xd3, 0x77, 0x07, 0x6e, 0x41, 0x57, 0xc9,
		0xd9, 0x1d, 0x75, 0xee, 0x42, 0x63, 0xdc, 0x58,
		0xad, 0xfc, 0xc7, 0xe1, 0x77, 0x49, 0xb1, 0x58,
		0x21, 0x96, 0x00, 0x55, 0x90, 0x6b, 0xf6, 0x2a,
		0x5a, 0x19, 0x25, 0x93, 0x59, 0x9d, 0xaf, 0x79,
		0x9b, 0x18, 0x5d, 0xf6, 0x5d, 0x64, 0x4b, 0x9a,
		0xf4, 0xde, 0xf2, 0x7f, 0xbd, 0x93, 0x7e, 0x45,
		0x3e, 0x17, 0xae, 0xbf, 0x52, 0xe1, 0xba, 0x8e,
		0x0b, 0xbc, 0x1e, 0x91, 0x9d, 0xf1, 0x4e, 0x0b,
		0xab, 0x9e, 0x5c, 0x4c, 0x6f, 0xf7, 0xf3, 0x8d,
		0x8c, 0x6d, 0xeb, 0x46, 0x05, 0x36, 0x7e, 0x2f,
		0x9c, 0xa1, 0x86, 0x15, 0xe1, 0xe4, 0xb4, 0x20,
		0x06, 0x44, 0x7b, 0x3c, 0x8b, 0x13, 0x96, 0xf5,
		0x02, 0xb1, 0x4f, 0x3c, 0x2d, 0x4a, 0x16, 0x03,
		0x01, 0x00, 0x86, 0x0f, 0x00, 0x00, 0x82, 0x00,
		0x80, 0x52, 0xb1, 0x0d, 0xfc, 0x85, 0x34, 0x56,
		0xb9, 0xdf, 0xa7, 0x8e, 0xf4, 0xfd, 0x02, 0x46,
		0x8a, 0x23, 0xcc, 0x53, 0x3b, 0x0f, 0xa7, 0x61,
		0xf3, 0xb5, 0xbf, 0xfe, 0x59, 0x77, 0x10, 0xd6,
		0x56, 0x93, 0x19, 0x6b, 0x2c, 0xf1, 0x35, 0x71,
		0xe3, 0x36, 0x2f, 0xa0, 0x90, 0x4e, 0x5a, 0xdf,
		0x8d, 0x06, 0x88, 0xcf, 0xb1, 0x06, 0x56, 0x8b,
		0x74, 0x8f, 0x02, 0x8e, 0x10, 0xd2, 0xab, 0x8d,
		0x3f, 0x3e, 0x02, 0xf1, 0x1a, 0x80, 0x6d, 0x0f,
		0x9e, 0x77, 0xd8, 0xfa, 0x92, 0xb3, 0x16, 0x40,
		0xeb, 0x9e, 0xca, 0xd7, 0xe4, 0x31, 0xcc, 0x63,
		0x5f, 0xe2, 0x4c, 0x85, 0x0e, 0xf2, 0xdd, 0xd3,
		0xfe, 0x7e, 0xa7, 0x60, 0x1c, 0xb4, 0x00, 0xd8,
		0xbe, 0x4b, 0x9b, 0x66, 0x78, 0x0f, 0xfb, 0x3b,
		0x52, 0x30, 0x2b, 0x8b, 0xd9, 0xef, 0x82, 0x0a,
		0xa4, 0x18, 0x1d, 0xb0, 0xb5, 0xbf, 0x54, 0x97,
		0x0c, 0x14, 0x03, 0x01, 0x00, 0x01, 0x01, 0x16,
		0x03, 0x01, 0x00, 0x30, 0xa1, 0x74, 0x22, 0xd8,
		0x86, 0x6a, 0xbe, 0x53, 0x34, 0x1d, 0xb3, 0x73,
		0xff, 0x51, 0xc0, 0xce, 0x8e, 0x7d, 0x9b, 0xab,
		0xcb, 0x8b, 0x79, 0xae, 0x04, 0x01, 0xa7, 0xf2,
		0x8e, 0x9d, 0xab, 0xa3, 0x73, 0x80, 0x5c, 0xff,
		0x96, 0x20, 0xbb, 0x8d, 0xc0, 0x02, 0x66, 0x6c,
		0x83, 0x4b, 0x78, 0x20,
	},
	{
		0x14, 0x03, 0x01, 0x00, 0x01, 0x01, 0x16, 0x03,
		0x01, 0x00, 0x30, 0x29, 0xd4, 0xfd, 0x03, 0x8b,
		0x30, 0x20, 0xf7, 0xca, 0xc0, 0x6c, 0x83, 0x5d,
		0x73, 0xcb, 0x81, 0x60, 0xe0, 0x9a, 0x09, 0xcb,
		0x33, 0x03, 0x80, 0x81, 0x4e, 0x84, 0x47, 0xd5,
		0x74, 0x6c, 0x3b, 0xb5, 0xc0, 0x48, 0x0d, 0x52,
		0xdd, 0xbe, 0xc2, 0x06, 0xf5, 0x79, 0x2b, 0x3e,
		0x99, 0x56, 0x94, 0x17, 0x03, 0x01, 0x00, 0x20,
		0x26, 0x46, 0x90, 0x9d, 0xef, 0x59, 0x00, 0xb6,
		0x70, 0xe8, 0x1e, 0x1a, 0x80, 0x8b, 0x04, 0xb2,
		0xfc, 0x51, 0xf8, 0x93, 0xbe, 0x00, 0x28, 0xba,
		0xb8, 0xdc, 0x51, 0x7e, 0x92, 0x80, 0xfa, 0xf2,
		0x17, 0x03, 0x01, 0x00, 0xe0, 0xb8, 0x2e, 0xc4,
		0x6b, 0x3f, 0xda, 0x39, 0x87, 0x7f, 0x03, 0x43,
		0x28, 0xdd, 0xb9, 0xf9, 0x9e, 0x16, 0xf5, 0xce,
		0x3f, 0x7e, 0x6a, 0x7b, 0xb3, 0x60, 0x14, 0xe1,
		0xea, 0x54, 0xc5, 0xe6, 0x05, 0x0a, 0x6c, 0xe0,
		0xef, 0x58, 0x29, 0x8a, 0x77, 0x64, 0x77, 0x5d,
		0x9c, 0xe2, 0xe0, 0x3c, 0x6d, 0x87, 0x82, 0xbe,
		0x47, 0x63, 0xd4, 0xfd, 0x0c, 0x25, 0xc4, 0xb1,
		0xfe, 0x29, 0x6f, 0x84, 0xfb, 0xab, 0x6e, 0xa7,
		0xf9, 0x22, 0x89, 0x97, 0x5b, 0x91, 0x0a, 0x07,
		0xe0, 0xef, 0x3d, 0x67, 0xee, 0x87, 0xa8, 0x33,
		0x02, 0x64, 0x33, 0xca, 0x15, 0x10, 0xb9, 0x57,
		0xd8, 0xe5, 0x1a, 0x4b, 0xe3, 0x45, 0xc1, 0x62,
		0x85, 0x50, 0xf1, 0x79, 0x54, 0xe1, 0x2e, 0x25,
		0x01, 0x3c, 0xdb, 0x2d, 0x39, 0x14, 0x2f, 0x9b,
		0xd0, 0x1d, 0xc1, 0xac, 0x73, 0x7d, 0xa4, 0xed,
		0x89, 0x98, 0xb1, 0xae, 0x8a, 0x9e, 0xc8, 0xa7,
		0xfe, 0x55, 0x27, 0xb5, 0xb5, 0xa2, 0xec, 0x7e,
		0xe3, 0x6b, 0x45, 0x19, 0xfa, 0x20, 0x1c, 0x33,
		0x83, 0x22, 0x33, 0x97, 0xd2, 0x5a, 0xc4, 0xf8,
		0x9a, 0x03, 0x13, 0x85, 0xf2, 0x2b, 0x04, 0x59,
		0x27, 0xd7, 0x0b, 0x42, 0x47, 0x9b, 0x7d, 0x4d,
		0xb2, 0x1a, 0x85, 0x7f, 0x97, 0xc2, 0xf2, 0x10,
		0xf0, 0xfa, 0x4e, 0x4b, 0x62, 0x43, 0x3a, 0x09,
		0x2e, 0xcd, 0x8f, 0xa8, 0xb6, 0x0b, 0x5f, 0x34,
		0xd7, 0x3b, 0xba, 0xd9, 0xe5, 0x01, 0x2d, 0x35,
		0xae, 0xc5, 0x4c, 0xab, 0x40, 0x64, 0xc2, 0xc9,
		0x8c, 0x69, 0x44, 0xf4, 0xb8, 0xb5, 0x3a, 0x05,
		0x3c, 0x29, 0x19, 0xb4, 0x09, 0x17, 0x03, 0x01,
		0x00, 0x20, 0xc8, 0xc5, 0xb7, 0xe3, 0xd2, 0x3e,
		0x27, 0xb5, 0x71, 0x8f, 0x52, 0x0b, 0xce, 0x17,
		0x64, 0x86, 0xa4, 0x34, 0x16, 0x1b, 0x61, 0x64,
		0x7c, 0xb3, 0xf2, 0xe5, 0x3e, 0xfd, 0xdd, 0xfb,
		0x40, 0x78, 0x17, 0x03, 0x01, 0x00, 0x50, 0x8e,
		0x79, 0xf0, 0x8e, 0x76, 0x5d, 0x34, 0x09, 0xdc,
		0xec, 0x6d, 0xc3, 0x43, 0x1d, 0xcb, 0x2d, 0xaa,
		0x08, 0x7a, 0x51, 0x94, 0x4e, 0xc5, 0x26, 0xe4,
		0x0b, 0x8e, 0x8f, 0x51, 0xf2, 0x9f, 0xeb, 0xc3,
		0x18, 0x43, 0x95, 0x15, 0xfc, 0x59, 0x18, 0x25,
		0x47, 0xb6, 0x4a, 0x6e, 0xa3, 0xa4, 0x3b, 0xa3,
		0x47, 0x34, 0x74, 0x6b, 0xc5, 0x3d, 0x41, 0x14,
		0x64, 0xd5, 0x69, 0x5f, 0x77, 0xf3, 0x7c, 0x41,
		0xc6, 0xed, 0x2e, 0xcf, 0xff, 0x40, 0xf2, 0xce,
		0xbb, 0xa7, 0x4e, 0x73, 0x88, 0x98, 0x10,
	},
	{
		0x15, 0x03, 0x01, 0x00, 0x20, 0x1a, 0xbc, 0x70,
		0x24, 0xf8, 0xfb, 0xf2, 0x4a, 0xf9, 0x44, 0x1e,
		0x58, 0xf8, 0xaa, 0x41, 0x24, 0xe8, 0x80, 0x33,
		0x45, 0x18, 0xa1, 0x5d, 0xee, 0x16, 0x80, 0xae,
		0x40, 0x41, 0x8e, 0x41, 0x9b,
	},
}
